@@ -6,7 +6,7 @@ use warnings;
 use Carp qw(croak);
 use Scalar::Util qw(weaken isweak);
 
-our $VERSION = '0.11';
+our $VERSION = '1.01';
 
 sub new {
     return bless {}, shift;
@@ -24,7 +24,7 @@ sub mock {
     else {
         $self = bless {}, __PACKAGE__;
         if (! defined wantarray){
-            croak "\n\ncalling mock() in void context isn't allowed.";
+            croak "\n\ncalling mock() in void context isn't allowed. ";
         }
     }
 
@@ -44,10 +44,7 @@ sub mock {
     push @{ $self->{return} }, $self->{return_value};
 
     $self->{name} = $sub;
-
-    if (! $fake) {
-        $self->{orig} = \&$sub;
-    }
+    $self->{orig} = \&$sub if ! $fake;
 
     my $called;
 
@@ -55,13 +52,13 @@ sub mock {
         no strict 'refs';
         no warnings 'redefine';
 
-
         *$sub = sub {
 
             weaken $self if ! isweak $self;
 
             @{ $self->{called_with} } = @_;
             $self->{called_count} = ++$called;
+
             if ($self->{side_effect}) {
                 if (wantarray){
                     my @effect = $self->{side_effect}->(@_);
@@ -73,7 +70,7 @@ sub mock {
                 }
             }
 
-            return undef if ! $self->{return};
+            return if ! $self->{return};
 
             return ! wantarray && @{ $self->{return} } == 1
                 ? $self->{return}[0]
@@ -137,10 +134,7 @@ sub _check_side_effect {
     }
 }
 sub DESTROY {
-    my $self = shift;
-    if (! $self->{keep_mock_on_destroy}){
-        $self->unmock;
-    }
+    $_[0]->unmock;
 }
 sub _end {}; # vim fold placeholder
 
@@ -181,7 +175,8 @@ Mock::Sub - Mock module, package, object and standard subroutines, with unit tes
     $foo->return_value(1, 2, {a => 1});
     my @return = Package::foo;
 
-    # have the mocked sub perform an action
+    # have the mocked sub perform an action (the side effect function receives
+    # the parameters sent into the mocked sub)
 
     $foo->side_effect( sub { die "eval catch"; } );
 
@@ -193,12 +188,13 @@ Mock::Sub - Mock module, package, object and standard subroutines, with unit tes
 
     my @args = $foo->called_with;
 
-    # reset the mocked sub for re-use within the same scope
+    # reset the mock object for re-use within the same scope (does not restore
+    # the mocked sub)
 
     $foo->reset;
 
     # restore original functionality to the sub (we do this by default on
-    # DESTROY())
+    # DESTROY()). This also calls reset() on the ojbect
 
     $foo->unmock;
 
@@ -272,7 +268,7 @@ MyModule::first).
 
 =head2 C<new>
 
-Instantiates and returns a new Mock::Sub object.
+Instantiates and returns a new C<Mock::Sub> object.
 
 =head2 C<mock('sub', %opts)>
 
@@ -290,27 +286,12 @@ Options:
 =item C<return_value>
 
 Set this to have the mocked sub return anything you wish (accepts a single
-scalar only. See C<return_value()> method to return a list).
+scalar only. See C<return_value()> method to return a list and for further
+information).
 
 =item C<side_effect>
 
-Send in a code reference containing an action you'd like the
-mocked sub to perform (C<die()> is useful for testing with C<eval()>).
-
-You can use both side_effect and return_value params at the same time.
-side_effect will be run first, and then return_value. Note that if
-side_effect's last expression evaluates to any value whatsoever (even false),
-it will return that and return_value will be skipped.
-
-To work around this and have the side_effect run but still get the
-return_value thereafter, write your cref to evaluate undef as the last thing
-it does: C<sub { ...; undef; }>.
-
-=item C<keep_mock_on_destroy>
-
-By default, we restore original sub functionality after the mock object goes
-out of scope. You can keep the mocked sub in place by setting this parameter
-to any true value.
+See C<side_effect()> method.
 
 =back
 
@@ -329,8 +310,8 @@ Returns the number of times the mocked sub has been called.
 
 =head2 C<called_with>
 
-Returns an array of the parameters sent to the subroutine. C<dies()> if we're
-called before the mocked sub has been called.
+Returns an array of the parameters sent to the subroutine. C<croak()s> if
+we're called before the mocked sub has been called.
 
 =head2 C<name>
 
@@ -338,8 +319,22 @@ Returns the full name of the sub being mocked, as entered into C<mock()>.
 
 =head2 C<side_effect($cref)>
 
-Add (or change/remove) a side effect after instantiation. Same rules apply
-here as they do for the C<side_effect> parameter.
+Add (or change/remove) a side effect after instantiation.
+
+Send in a code reference containing an action you'd like the
+mocked sub to perform (C<die()> is useful for testing with C<eval()>).
+
+The side effect function will receive all parameters sent into the mocked sub.
+
+You can use both C<side_effect()> and C<return_value()> params at the same
+time. C<side_effect> will be run first, and then C<return_value>. Note that if
+C<side_effect>'s last expression evaluates to any value whatsoever
+(even false), it will return that and C<return_value> will be skipped.
+
+To work around this and have the side_effect run but still get the
+return_value thereafter, write your cref to evaluate undef as the last thing
+it does: C<sub { ...; undef; }>.
+
 
 =head2 C<return_value>
 
